---
name: Feature request
about: Suggest an idea for this project
title: '[FEATURE]'
labels: feature request
assignees: ''

---

**Missing functionality**
<!-- 
Is your feature request related to a problem or a gap in functionality?
Give a clear and concise description of what the problem is. Try to ellaborate wth examples with text, code-snippets, visuals or links to resources.

Example: 
   I think adding this would help us when [...] 
   We could change this feature to work with [...] 

Please let the title reflect this intent.
-->

**Proposed feature**
<!--
Describe the solution you'd like
A clear and concise description of what you want to happen. Try to ellaborate wth examples with text, code-snippets, visuals or links to resources.

Please let the title reflect this intent.
-->

**Alternatives considered**
<!--
Describe alternatives you've considered
A clear and concise description of any alternative solutions or features you've considered. Try to ellaborate wth examples with text, code-snippets, visuals or links to resources.
-->

**Additional context**
<!-- 
Add any other context or screenshots about the feature request here. 
-->